| Type: | Package |
| Title: | Helper Package for Installing 'OpenCV' |
| Version: | 4.130.0 |
| Date: | 2026-05-13 |
| Description: | Installs 'OpenCV' for use by other packages. 'OpenCV' https://opencv.org/ is library of programming functions mainly aimed at real-time computer vision. This 'Lite' version installs the stable base version of 'OpenCV' and some of its experimental externally contributed modules. It does not provide R bindings directly. |
| License: | GPL-3 |
| Imports: | utils, parallel |
| SystemRequirements: | cmake |
| RoxygenNote: | 7.3.3 |
| Biarch: | false |
| Encoding: | UTF-8 |
| Depends: | R (≥ 4.0.0) |
| Suggests: | covr, knitr, rmarkdown, testthat (≥ 3.0.0) |
| Config/testthat/edition: | 3 |
| VignetteBuilder: | knitr |
| URL: | https://swarm-lab.github.io/ROpenCVLite/, https://github.com/swarm-lab/ROpenCVLite |
| BugReports: | https://github.com/swarm-lab/ROpenCVLite/issues |
| NeedsCompilation: | no |
| Packaged: | 2026-05-21 13:12:12 UTC; simon |
| Author: | Simon Garnier |
| Maintainer: | Simon Garnier <garnier@njit.edu> |
| Repository: | CRAN |
| Date/Publication: | 2026-05-21 17:30:02 UTC |
ROpenCVLite: A package to install OpenCV within R
Description
This is a utility package that installs OpenCV within R for use by other packages. This Lite version does not contain any of the contributed modules of OpenCV.
Author(s)
Simon Garnier, garnier@njit.edu
See Also
Useful links:
Report bugs at https://github.com/swarm-lab/ROpenCVLite/issues
Install Location of OpenCV
Description
This function returns the location at which OpenCV is installed.
Usage
OpenCVPath()
Value
A character string.
Author(s)
Simon Garnier, garnier@njit.edu
Examples
## Not run:
OpenCVPath()
## End(Not run)
Default Install Location of OpenCV
Description
This function returns the location at which OpenCV should be installed by default.
Usage
defaultOpenCVPath()
Value
A character string.
Author(s)
Simon Garnier, garnier@njit.edu
Examples
defaultOpenCVPath()
Install OpenCV
Description
This function attempts to download, compile and install OpenCV on the system. This process will take several minutes.
Usage
installOpenCV(
install_path = defaultOpenCVPath(),
batch = FALSE,
use_ccache = FALSE,
optimize_for_host = FALSE,
modules = c("calib3d", "core", "dnn", "features2d", "flann", "gapi", "highgui",
"imgcodecs", "imgproc", "ml", "objdetect", "photo", "stitching", "video", "videoio",
"ximgproc", "wechat_qrcode")
)
Arguments
install_path |
A character string indicating the location at which
OpenCV should be installed. By default, it is the value returned by
|
batch |
A boolean indicating whether to skip ( |
use_ccache |
A boolean indicating whether to use |
optimize_for_host |
A boolean indicating whether to let CMake detect
and use the host CPU's full instruction set ( |
modules |
A character vector of OpenCV modules to compile. Defaults to
the full set supported by |
Value
A boolean.
Author(s)
Simon Garnier, garnier@njit.edu
Examples
## Not run:
installOpenCV()
## End(Not run)
Check Cmake Installation
Description
This function checks that Cmake is installed on the system.
Usage
isCmakeInstalled()
Value
A boolean.
Author(s)
Simon Garnier, garnier@njit.edu
Examples
isCmakeInstalled()
Check OpenCV Installation
Description
This function checks that OpenCV is installed and accessible.
Usage
isOpenCVInstalled()
Value
A boolean.
Author(s)
Simon Garnier, garnier@njit.edu
Examples
isOpenCVInstalled()
C/C++ configuration options
Description
This function returns the configuration options for compiling
C/C++-based packages against OpenCV installed by ROpenCVLite.
Usage
opencvConfig(output = "libs", arch = NULL)
Arguments
output |
Either 'libs' for library configuration options or 'cflags' for C/C++ configuration flags. |
arch |
architecture relevant for Windows. If |
Value
A concatenated character string (with cat) of the
configuration options.
Author(s)
Simon Garnier, garnier@njit.edu
Examples
## Not run:
if (isOpenCVInstalled()) {
opencvConfig()
opencvConfig(output = "cflags")
opencvConfig(arch = R.version$arch)
}
## End(Not run)
OpenCV Version
Description
This function determines the version of OpenCV installed within R.
Usage
opencvVersion()
Value
A character string.
Author(s)
Simon Garnier, garnier@njit.edu
Examples
if (isOpenCVInstalled()) {
opencvVersion()
}
Remove OpenCV
Description
This function removes OpenCV from the system.
Usage
removeOpenCV()
Value
A boolean.
Author(s)
Simon Garnier, garnier@njit.edu
Examples
## Not run:
installOpenCV()
## End(Not run)